# Introduction

It is used to generate tables of scores for bridge games


````
pip install pbr # install package
pbr sample      # generate sample xlsx for reference
pbr student-group1.xlsx
````

# Contact

* gopher in xinrui app
